import {
    Chart,
    Colors,
    Legend,
    LineController,
    LineElement,
    PointElement,
    CategoryScale,
    LinearScale
} from 'chart.js';

Chart.register(
    Colors,
    Legend,
    LineController,
    LineElement,
    PointElement,
    CategoryScale,
    LinearScale
);

export var simplesitestats = {};

simplesitestats.roundTimestamp = function(t) {
    return t.substr(0, 10);
};

simplesitestats.allTimestamps = function(timeseries) {
    // Find set of unique timestamps.
    var tmp = {};
    for (var i = 0; i < timeseries.length; i++) {
        for (var j = 0; j < timeseries[i].data.length; j++) {
            var t = timeseries[i].data[j].t;
            tmp[t] = true;
        }
    }
    var unsortedTimestamps = Object.keys(tmp);
    return unsortedTimestamps.sort((a, b) => a > b);
};

simplesitestats.chart = function(el, timeseries) {
    var stack = undefined;

    timeseries = timeseries.map((x) => {
        for (var j = 0; j < x.data.length; j++) {
            x.data[j].t = simplesitestats.roundTimestamp(x.data[j].t);
        }
        x.stack = stack;
        x.label = x.value;
        return x;
    });

    timeseries.sort((a, b) => (
        (b.data[b.data.length-1].n) - (a.data[a.data.length-1].n)));

    const cfg = {
        type: 'line',
        data: {
            datasets: timeseries,
            labels: simplesitestats.allTimestamps(timeseries),
        },
        options: {
            animation: false,
            parsing: {
                labelKey: 'value',
                xAxisKey: 't',
                yAxisKey: 'n',
            },
            datasets: {
                line: {
                    spanGaps: false,
                },
            },
            plugins: {
                tooltip: {
                    enabled: false,
                },
                legend: {
                    position: 'right',
                    align: 'left',
                    labels: {
                        boxWidth: 20,
                    },
                },
            },
        },
    };

    console.log(cfg);

    new Chart(el, cfg);
};

document.addEventListener("DOMContentLoaded", function() {
    document.querySelectorAll('.simplesitestats-chart').forEach(el => {
        var jsonData = document.getElementById(el.dataset.timeseriesElementId).innerText;
        console.log(jsonData);
        var timeseries = JSON.parse(jsonData);
        simplesitestats.chart(el, timeseries);
    });
});
